{% extends 'bee_django_course/base.html' %}

{% block content %}
    <video width='320' height='240' controls id="videos_1">
        <source src="https://zenweiqi.gensee.com/webcast/site/vod/play-23fed349099348a29cf564a9bacefd63" type="video/mp4">
        您de浏览器不支持播放
    </video>




{% endblock content %}

{% block scripts %}

{% endblock scripts %}